<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: Products (c) 2008 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to allow users to create, manage
#  and display products in a variety of ways.
# 
# Version: 1.1.5
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

class hierarchy_ops
{
  private static $_allhierarchy;


  public static function get_all_hierarchy_info()
  {
    if( !is_array(self::$_allhierarchy) )
      {
	$db = cmsms()->GetDb();
	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_hierarchy';
	$tmp = $db->GetAll($query);
	if( is_array($tmp) )
	  {
	    self::$_allhierarchy = cge_array::to_hash($tmp,'id');
	  }
	return self::$_allhierarchy;
      }
  }


  public static function get_hierarchy_info($hierarchy_id)
  {
    if( !is_array(self::$_allhierarchy))
      {
	self::get_all_hierarchy_info();
      }

    if( is_array(self::$_allhierarchy) && isset(self::$_allhierarchy[$hierarchy_id]) )
      {
	return self::$_allhierarchy[$hierarchy_id];
      }
  }


  public static function get_hierarchy_path($hier_id)
  {
    $out = array();
    while( $hier_id > 0 )
      {
	$out[] = $hier_id;

	$hier_info = self::get_hierarchy_info($hier_id);
	if( !$hier_info ) break;

	$hier_id = $hier_info['parent_id'];
	if( $hier_id < 0 ) break;
      }

    return array_reverse($out);
  }

} // end of class

#
# EOF
#
?>